# Session

[Licensecheck Index](../README.md#licensecheck-index) / [Licensecheck](./index.md#licensecheck) / Session

> Auto-generated documentation for [licensecheck.session](../../../licensecheck/session.py) module.
- [Session](#session)
